from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LimitCls:
	"""Limit commands group definition. 18 total commands, 12 Subgroups, 1 group commands
	Repeated Capability: LimitIx, default value after init: LimitIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("limit", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_limitIx_get', 'repcap_limitIx_set', repcap.LimitIx.Nr1)

	def repcap_limitIx_set(self, limitIx: repcap.LimitIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to LimitIx.Default
		Default value after init: LimitIx.Nr1"""
		self._cmd_group.set_repcap_enum_value(limitIx)

	def repcap_limitIx_get(self) -> repcap.LimitIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def clear(self):
		"""clear commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clear'):
			from .Clear import ClearCls
			self._clear = ClearCls(self._core, self._cmd_group)
		return self._clear

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def fail(self):
		"""fail commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fail'):
			from .Fail import FailCls
			self._fail = FailCls(self._core, self._cmd_group)
		return self._fail

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def copy(self):
		"""copy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_copy'):
			from .Copy import CopyCls
			self._copy = CopyCls(self._core, self._cmd_group)
		return self._copy

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def active(self):
		"""active commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_active'):
			from .Active import ActiveCls
			self._active = ActiveCls(self._core, self._cmd_group)
		return self._active

	@property
	def control(self):
		"""control commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	@property
	def lower(self):
		"""lower commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_lower'):
			from .Lower import LowerCls
			self._lower = LowerCls(self._core, self._cmd_group)
		return self._lower

	@property
	def upper(self):
		"""upper commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_upper'):
			from .Upper import UpperCls
			self._upper = UpperCls(self._core, self._cmd_group)
		return self._upper

	def delete(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:DELete \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.delete(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command deletes a limit line. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:DELete')

	def delete_with_opc(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		"""SCPI: CALCulate<n>:LIMit<li>:DELete \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.delete_with_opc(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command deletes a limit line. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:DELete', opc_timeout_ms)

	def clone(self) -> 'LimitCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LimitCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CompensationCls:
	"""Compensation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("compensation", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:FSK:DEViation:COMPensation \n
		Snippet: driver.applications.k70Vsa.calculate.fsk.deviation.compensation.set(state = False, window = repcap.Window.Default) \n
		This command defines whether the deviation error is compensated for when calculating the frequency error for FSK
		modulation. Note that this command is maintained for compatibility reasons only. For newer remote programs,
		use [SENSe:]DDEMod:NORMalize:FDERror. \n
			:param state: ON | 1 Scales the reference signal to the actual deviation of the measurement signal. OFF | 0 Uses the entered nominal deviation for the reference signal.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:FSK:DEViation:COMPensation {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:FSK:DEViation:COMPensation \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.fsk.deviation.compensation.get(window = repcap.Window.Default) \n
		This command defines whether the deviation error is compensated for when calculating the frequency error for FSK
		modulation. Note that this command is maintained for compatibility reasons only. For newer remote programs,
		use [SENSe:]DDEMod:NORMalize:FDERror. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | 1 Scales the reference signal to the actual deviation of the measurement signal. OFF | 0 Uses the entered nominal deviation for the reference signal."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:FSK:DEViation:COMPensation?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WindowCls:
	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	def set(self, window_name: str, window_type: enums.WindowTypeK30) -> None:
		"""SCPI: LAYout:REPLace[:WINDow] \n
		Snippet: driver.applications.k30NoiseFigure.layout.replace.window.set(window_name = '1', window_type = enums.WindowTypeK30.CalPowerCold=CPCold) \n
		This command replaces the window type (for example from 'Diagram' to 'Result Summary') of an already existing window in
		the active channel while keeping its position, index and window name. To add a new window, use the method RsFswp.Layout.
		Add.Window.get_ command. \n
			:param window_name: String containing the name of the existing window. By default, the name of a window is the same as its index. To determine the name and index of all active windows in the active channel, use the method RsFswp.Layout.Catalog.Window.get_ query.
			:param window_type: (enum or string) Type of result display you want to use in the existing window. See method RsFswp.Layout.Add.Window.get_ for a list of available window types.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('window_name', window_name, DataType.String), ArgSingle('window_type', window_type, DataType.EnumExt, enums.WindowTypeK30))
		self._core.io.write_with_opc(f'LAYout:REPLace:WINDow {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EgateCls:
	"""Egate commands group definition. 15 total commands, 8 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("egate", core, parent)

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def polarity(self):
		"""polarity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_polarity'):
			from .Polarity import PolarityCls
			self._polarity = PolarityCls(self._core, self._cmd_group)
		return self._polarity

	@property
	def holdoff(self):
		"""holdoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_holdoff'):
			from .Holdoff import HoldoffCls
			self._holdoff = HoldoffCls(self._core, self._cmd_group)
		return self._holdoff

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def level(self):
		"""level commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def trace(self):
		"""trace commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe \n
		Snippet: driver.sense.sweep.egate.set(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SWEep:EGATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:SWEep:EGATe \n
		Snippet: value: bool = driver.sense.sweep.egate.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'EgateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EgateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqcThresholdCls:
	"""IqcThreshold commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iqcThreshold", core, parent)

	def set(self, correlation_lev: float) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:IQCThreshold \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.iqcThreshold.set(correlation_lev = 1.0) \n
		This command sets the I/Q correlation threshold for pattern matching in percent. A high level means stricter matching. \n
			:param correlation_lev: Range: 10.0 to 100.0, Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(correlation_lev)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:IQCThreshold {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:IQCThreshold \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.search.sync.iqcThreshold.get() \n
		This command sets the I/Q correlation threshold for pattern matching in percent. A high level means stricter matching. \n
			:return: correlation_lev: Range: 10.0 to 100.0, Unit: PCT"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:IQCThreshold?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PerrorCls:
	"""Perror commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("perror", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:PERRor \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.perror.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the phase error measurement performed for digital demodulation. \n
			:param result_type: none 'Phase error' of display points of current sweep AVG Average of phase errors over several sweeps PAVG Average of maximum phase errors over several sweeps PCTL 95% percentile of phase error over several sweeps PEAK Maximum phase error over all symbols of current sweep PPCT 95% percentile of maximum phase errors over several sweeps PSD Standard deviation of maximum phase errors over several sweeps RPE Maximum value of phase error over several sweeps SDEV Standard deviation of phase errors over several sweeps TPE Maximum phase error over all display points over several sweeps
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:PERRor? {param}')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NstateCls:
	"""Nstate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nstate", core, parent)

	def set(self, pskn_state: float) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:PSK:NSTate \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.psk.nstate.set(pskn_state = 1.0) \n
		Together with DDEMod:PATT:PSK:FORMat, this command defines the demodulation order for PSK for the pattern (see also
		[SENSe:]DDEMod:PATTern:PSK:FORMat) . Depending on the demodulation format and state, the following orders are available:
			Table Header: <PSKNSTATe> / FORMat / Order \n
			- 2 / any / BPSK
			- 8 / NORMal / 8PSK
			- 8 / DIFFerential / D8PSK
		This command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param pskn_state: 2 | 8
		"""
		param = Conversions.decimal_value_to_str(pskn_state)
		self._core.io.write(f'SENSe:DDEMod:PATTern:PSK:NSTate {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:PATTern:PSK:NSTate \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.pattern.psk.nstate.get() \n
		Together with DDEMod:PATT:PSK:FORMat, this command defines the demodulation order for PSK for the pattern (see also
		[SENSe:]DDEMod:PATTern:PSK:FORMat) . Depending on the demodulation format and state, the following orders are available:
			Table Header: <PSKNSTATe> / FORMat / Order \n
			- 2 / any / BPSK
			- 8 / NORMal / 8PSK
			- 8 / DIFFerential / D8PSK
		This command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: pskn_state: 2 | 8"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:PSK:NSTate?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AreaCls:
	"""Area commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("area", core, parent)

	def set(self, x_1: float, y_1: float, x_2: float, y_2: float, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:ZOOM:AREA \n
		Snippet: driver.display.window.subwindow.zoom.area.set(x_1 = 1.0, y_1 = 1.0, x_2 = 1.0, y_2 = 1.0, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default) \n
		This command defines the zoom area. To define a zoom area, you first have to turn the zoom on. \n
			:param x_1: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			:param y_1: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			:param x_2: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			:param y_2: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('x_1', x_1, DataType.Float), ArgSingle('y_1', y_1, DataType.Float), ArgSingle('x_2', x_2, DataType.Float), ArgSingle('y_2', y_2, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:ZOOM:AREA {param}'.rstrip())

	# noinspection PyTypeChecker
	class AreaStruct(StructBase):
		"""Response structure. Fields: \n
			- X_1: float: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			- Y_1: float: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			- X_2: float: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT
			- Y_2: float: Diagram coordinates in % of the complete diagram that define the zoom area. The lower left corner is the origin of coordinate system. The upper right corner is the end point of the system. Range: 0 to 100, Unit: PCT"""
		__meta_args_list = [
			ArgStruct.scalar_float('X_1'),
			ArgStruct.scalar_float('Y_1'),
			ArgStruct.scalar_float('X_2'),
			ArgStruct.scalar_float('Y_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.X_1: float = None
			self.Y_1: float = None
			self.X_2: float = None
			self.Y_2: float = None

	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default) -> AreaStruct:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:ZOOM:AREA \n
		Snippet: value: AreaStruct = driver.display.window.subwindow.zoom.area.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default) \n
		This command defines the zoom area. To define a zoom area, you first have to turn the zoom on. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:return: structure: for return value, see the help for AreaStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		return self._core.io.query_struct(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:ZOOM:AREA?', self.__class__.AreaStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PredictedCls:
	"""Predicted commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("predicted", core, parent)

	def export(self, filename: str) -> None:
		"""SCPI: [SENSe]:FPLan:PREDicted:EXPort \n
		Snippet: driver.applications.k50Spurious.sense.fplan.predicted.export(filename = '1') \n
		Saves the current predicted list to a .csv file. \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:FPLan:PREDicted:EXPort {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScalingCls:
	"""Scaling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scaling", core, parent)

	def set(self, scaling_type: enums.ScalingMode) -> None:
		"""SCPI: [SENSe]:CORRection:TRANsducer:SCALing \n
		Snippet: driver.sense.correction.transducer.scaling.set(scaling_type = enums.ScalingMode.LINear) \n
		No command help available \n
			:param scaling_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(scaling_type, enums.ScalingMode)
		self._core.io.write(f'SENSe:CORRection:TRANsducer:SCALing {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ScalingMode:
		"""SCPI: [SENSe]:CORRection:TRANsducer:SCALing \n
		Snippet: value: enums.ScalingMode = driver.sense.correction.transducer.scaling.get() \n
		No command help available \n
			:return: scaling_type: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:TRANsducer:SCALing?')
		return Conversions.str_to_scalar_enum(response, enums.ScalingMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OverlapCls:
	"""Overlap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("overlap", core, parent)

	def set(self, overlap: float) -> None:
		"""SCPI: [SENSe]:IQ:FFT:WINDow:OVERlap \n
		Snippet: driver.applications.iqAnalyzer.sense.iq.fft.window.overlap.set(overlap = 1.0) \n
		Defines the part of a single FFT window that is re-calculated by the next FFT calculation. \n
			:param overlap: double value Percentage rate Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(overlap)
		self._core.io.write(f'SENSe:IQ:FFT:WINDow:OVERlap {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:IQ:FFT:WINDow:OVERlap \n
		Snippet: value: float = driver.applications.iqAnalyzer.sense.iq.fft.window.overlap.get() \n
		Defines the part of a single FFT window that is re-calculated by the next FFT calculation. \n
			:return: overlap: No help available"""
		response = self._core.io.query_str(f'SENSe:IQ:FFT:WINDow:OVERlap?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HoldoffCls:
	"""Holdoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("holdoff", core, parent)

	def set(self, time: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:RFPower:HOLDoff \n
		Snippet: driver.trigger.sequence.rfPower.holdoff.set(time = 1.0) \n
		No command help available \n
			:param time: No help available
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'TRIGger:SEQuence:RFPower:HOLDoff {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:RFPower:HOLDoff \n
		Snippet: value: float = driver.trigger.sequence.rfPower.holdoff.get() \n
		No command help available \n
			:return: time: No help available"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:RFPower:HOLDoff?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:SELect \n
		Snippet: driver.sense.correction.cvl.select.set(filename = '1') \n
		This command selects the conversion loss table with the specified file name. If <file_name> is not available, a new
		conversion loss table is created. This command is only available with option B21 (External Mixer) installed. \n
			:param filename: String containing the path and name of the file.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:CORRection:CVL:SELect {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 5 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	@property
	def step(self):
		"""step commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_step'):
			from .Step import StepCls
			self._step = StepCls(self._core, self._cmd_group)
		return self._step

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer \n
		Snippet: driver.sense.frequency.center.set(frequency = 1.0) \n
		This command defines the center frequency. \n
			:param frequency: The allowed range and fmax is specified in the data sheet. Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:FREQuency:CENTer {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:CENTer \n
		Snippet: value: float = driver.sense.frequency.center.get() \n
		This command defines the center frequency. \n
			:return: frequency: The allowed range and fmax is specified in the data sheet. Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'CenterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CenterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DtimeCls:
	"""Dtime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dtime", core, parent)

	def set(self, dropout_time: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:DTIMe \n
		Snippet: driver.trigger.sequence.dtime.set(dropout_time = 1.0) \n
		Defines the time the input signal must stay below the trigger level before a trigger is detected again. \n
			:param dropout_time: Dropout time of the trigger. Range: 0 s to 10.0 s , Unit: S
		"""
		param = Conversions.decimal_value_to_str(dropout_time)
		self._core.io.write(f'TRIGger:SEQuence:DTIMe {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:DTIMe \n
		Snippet: value: float = driver.trigger.sequence.dtime.get() \n
		Defines the time the input signal must stay below the trigger level before a trigger is detected again. \n
			:return: dropout_time: Dropout time of the trigger. Range: 0 s to 10.0 s , Unit: S"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:DTIMe?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MnumberCls:
	"""Mnumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mnumber", core, parent)

	def set(self, mharm: float) -> None:
		"""SCPI: [SENSe]:CREFerence:HARMonics:MNUMber \n
		Snippet: driver.applications.k50Spurious.sense.creference.harmonics.mnumber.set(mharm = 1.0) \n
		Sets the maximum harmonics number to be measured. \n
			:param mharm: numeric value
		"""
		param = Conversions.decimal_value_to_str(mharm)
		self._core.io.write(f'SENSe:CREFerence:HARMonics:MNUMber {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CREFerence:HARMonics:MNUMber \n
		Snippet: value: float = driver.applications.k50Spurious.sense.creference.harmonics.mnumber.get() \n
		Sets the maximum harmonics number to be measured. \n
			:return: mharm: No help available"""
		response = self._core.io.query_str(f'SENSe:CREFerence:HARMonics:MNUMber?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IntervalCls:
	"""Interval commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interval", core, parent)

	def set(self, span: float) -> None:
		"""SCPI: [SENSe]:CREFerence:GUARd:INTerval \n
		Snippet: driver.applications.k50Spurious.sense.creference.guard.interval.set(span = 1.0) \n
		Defines the guard interval as a span around the reference carrier.
		This setting is only available for [SENSe:]CREFerence:GUARd:STATe OFF \n
			:param span: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(span)
		self._core.io.write(f'SENSe:CREFerence:GUARd:INTerval {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CREFerence:GUARd:INTerval \n
		Snippet: value: float = driver.applications.k50Spurious.sense.creference.guard.interval.get() \n
		Defines the guard interval as a span around the reference carrier.
		This setting is only available for [SENSe:]CREFerence:GUARd:STATe OFF \n
			:return: span: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:CREFerence:GUARd:INTerval?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PointsCls:
	"""Points commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("points", core, parent)

	def set(self, sweep_points: int) -> None:
		"""SCPI: [SENSe]:SWEep:POINts \n
		Snippet: driver.sense.sweep.points.set(sweep_points = 1) \n
		No command help available \n
			:param sweep_points: No help available
		"""
		param = Conversions.decimal_value_to_str(sweep_points)
		self._core.io.write(f'SENSe:SWEep:POINts {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:SWEep:POINts \n
		Snippet: value: int = driver.sense.sweep.points.get() \n
		No command help available \n
			:return: sweep_points: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:POINts?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PresetRefLevelCls:
	"""PresetRefLevel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("presetRefLevel", core, parent)

	def set(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:PRESet:RLEVel \n
		Snippet: driver.sense.power.achannel.presetRefLevel.set() \n
		No command help available \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:POWer:ACHannel:PRESet:RLEVel', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExecuteCls:
	"""Execute commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("execute", core, parent)

	def get(self) -> bool:
		"""SCPI: DIAGnostic:SERVice:SPCHeck:EXECute \n
		Snippet: value: bool = driver.diagnostic.service.spCheck.execute.get() \n
		No command help available \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:SPCHeck:EXECute?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.IfGainModeDdem) -> None:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:MODE \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.equalizer.mode.set(mode = enums.IfGainModeDdem.AVERaging) \n
		Switches between the equalizer modes. For details see 'The equalizer'. \n
			:param mode: NORMal Switches the equalizer on for the next sweep. TRACking Switches the equalizer on; the results of the equalizer in the previous sweep are considered to calculate the new filter. FREeze The filter is no longer changed, the current equalizer values are used for subsequent sweeps. USER A user-defined equalizer loaded from a file is used. AVERaging Switches the equalizer on; the results of the equalizer in all previous sweeps (since the instrument was switched on or the equalizer was reset) are considered to calculate the new filter. To start a new averaging process, use the [SENSe:]DDEMod:EQUalizer:RESet command.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.IfGainModeDdem)
		self._core.io.write(f'SENSe:DDEMod:EQUalizer:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.IfGainModeDdem:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:MODE \n
		Snippet: value: enums.IfGainModeDdem = driver.applications.k70Vsa.sense.ddemod.equalizer.mode.get() \n
		Switches between the equalizer modes. For details see 'The equalizer'. \n
			:return: mode: NORMal Switches the equalizer on for the next sweep. TRACking Switches the equalizer on; the results of the equalizer in the previous sweep are considered to calculate the new filter. FREeze The filter is no longer changed, the current equalizer values are used for subsequent sweeps. USER A user-defined equalizer loaded from a file is used. AVERaging Switches the equalizer on; the results of the equalizer in all previous sweeps (since the instrument was switched on or the equalizer was reset) are considered to calculate the new filter. To start a new averaging process, use the [SENSe:]DDEMod:EQUalizer:RESet command."""
		response = self._core.io.query_str(f'SENSe:DDEMod:EQUalizer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.IfGainModeDdem)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self) -> bool:
		"""SCPI: [SENSe]:DDEMod:FSYNc:RESult \n
		Snippet: value: bool = driver.applications.k70Vsa.sense.ddemod.fsync.result.get() \n
		Queries the result of the fine sync. \n
			:return: result: ON | OFF | 0 | 1 OFF | 0 fine sync with known data failed ON | 1 fine sync with known data successful"""
		response = self._core.io.query_str(f'SENSe:DDEMod:FSYNc:RESult?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:AUTO \n
		Snippet: driver.massMemory.load.auto.set(filename = '1') \n
		This command restores an instrument configuration and defines that configuration as the default state. The default state
		is restored after a preset (*RST) or after you turn on the R&S FSWP. \n
			:param filename: 'Factory' Restores the factory settings as the default state. 'file_name String containing the path and name of the configuration file. Note that only instrument settings files can be selected for the startup recall function; channel files cause an error.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write_with_opc(f'MMEMory:LOAD:AUTO 1, {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisconnectCls:
	"""Disconnect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("disconnect", core, parent)

	def set(self, drive: str, state: bool = None) -> None:
		"""SCPI: MMEMory:NETWork:DISConnect \n
		Snippet: driver.massMemory.network.disconnect.set(drive = '1', state = False) \n
		This command disconnects a network drive. \n
			:param drive: String containing the drive name.
			:param state: 1 | 0 | ON | OFF Optional: determines whether disconnection is forced or not 1 | ON Disconnection is forced. 0 | OFF Disconnect only if not in use.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('drive', drive, DataType.String), ArgSingle('state', state, DataType.Boolean, None, is_optional=True))
		self._core.io.write(f'MMEMory:NETWork:DISConnect {param}'.rstrip())

	# noinspection PyTypeChecker
	class DisconnectStruct(StructBase):
		"""Response structure. Fields: \n
			- Drive: str: String containing the drive name.
			- State: bool: 1 | 0 | ON | OFF Optional: determines whether disconnection is forced or not 1 | ON Disconnection is forced. 0 | OFF Disconnect only if not in use."""
		__meta_args_list = [
			ArgStruct.scalar_str('Drive'),
			ArgStruct.scalar_bool('State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Drive: str = None
			self.State: bool = None

	def get(self) -> DisconnectStruct:
		"""SCPI: MMEMory:NETWork:DISConnect \n
		Snippet: value: DisconnectStruct = driver.massMemory.network.disconnect.get() \n
		This command disconnects a network drive. \n
			:return: structure: for return value, see the help for DisconnectStruct structure arguments."""
		return self._core.io.query_struct(f'MMEMory:NETWork:DISConnect?', self.__class__.DisconnectStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EqualizerCls:
	"""Equalizer commands group definition. 7 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("equalizer", core, parent)

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def load(self):
		"""load commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_load'):
			from .Load import LoadCls
			self._load = LoadCls(self._core, self._cmd_group)
		return self._load

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def save(self):
		"""save commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_save'):
			from .Save import SaveCls
			self._save = SaveCls(self._core, self._cmd_group)
		return self._save

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def reset(self) -> None:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:RESet \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.equalizer.reset() \n
		This command deletes the data of the currently selected equalizer. After deletion, training can start again using the
		command DDEM:EQU:MODE TRA (see [SENSe:]DDEMod:EQUalizer:MODE) . \n
		"""
		self._core.io.write(f'SENSe:DDEMod:EQUalizer:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:RESet \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.equalizer.reset_with_opc() \n
		This command deletes the data of the currently selected equalizer. After deletion, training can start again using the
		command DDEM:EQU:MODE TRA (see [SENSe:]DDEMod:EQUalizer:MODE) . \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:DDEMod:EQUalizer:RESet', opc_timeout_ms)

	def clone(self) -> 'EqualizerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EqualizerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, source: enums.InputSourceB) -> None:
		"""SCPI: INPut:SELect \n
		Snippet: driver.applications.k60Transient.inputPy.select.set(source = enums.InputSourceB.FIQ) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSWP. \n
			:param source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFswp.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.InputSourceB)
		self._core.io.write(f'INPut:SELect {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InputSourceB:
		"""SCPI: INPut:SELect \n
		Snippet: value: enums.InputSourceB = driver.applications.k60Transient.inputPy.select.get() \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSWP. \n
			:return: source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFswp.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'."""
		response = self._core.io.query_str(f'INPut:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.InputSourceB)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, rangePy=repcap.RangePy.Default) -> int:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:COUNt \n
		Snippet: value: int = driver.applications.k50Spurious.sense.listPy.range.count.get(rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: result: No help available"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:COUNt?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdivisionCls:
	"""Pdivision commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdivision", core, parent)

	def set(self, grid_spacing: float, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:PDIVision \n
		Snippet: driver.display.window.subwindow.trace.y.scale.pdivision.set(grid_spacing = 1.0, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This remote command determines the grid spacing on the Y-axis for all diagrams, where possible. In spectrum displays, for
		example, this command is not available. \n
			:param grid_spacing: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(grid_spacing)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:PDIVision {param}')

	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:PDIVision \n
		Snippet: value: float = driver.display.window.subwindow.trace.y.scale.pdivision.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This remote command determines the grid spacing on the Y-axis for all diagrams, where possible. In spectrum displays, for
		example, this command is not available. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: grid_spacing: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:PDIVision?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NbinsCls:
	"""Nbins commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nbins", core, parent)

	def set(self, bins: int, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DISTribution:NBINs \n
		Snippet: driver.applications.k60Transient.calculate.distribution.nbins.set(bins = 1, window = repcap.Window.Default) \n
		Defines the number of columns on the x-axis, i.e. the number of measurement value ranges for which the occurrences are
		determined. \n
			:param bins: Number of columns Range: 1 to 1000
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(bins)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:DISTribution:NBINs {param}')

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: CALCulate<n>:DISTribution:NBINs \n
		Snippet: value: int = driver.applications.k60Transient.calculate.distribution.nbins.get(window = repcap.Window.Default) \n
		Defines the number of columns on the x-axis, i.e. the number of measurement value ranges for which the occurrences are
		determined. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: bins: Number of columns Range: 1 to 1000"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:DISTribution:NBINs?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CvlCls:
	"""Cvl commands group definition. 11 total commands, 10 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cvl", core, parent)

	@property
	def band(self):
		"""band commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_band'):
			from .Band import BandCls
			self._band = BandCls(self._core, self._cmd_group)
		return self._band

	@property
	def bias(self):
		"""bias commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bias'):
			from .Bias import BiasCls
			self._bias = BiasCls(self._core, self._cmd_group)
		return self._bias

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def harmonic(self):
		"""harmonic commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_harmonic'):
			from .Harmonic import HarmonicCls
			self._harmonic = HarmonicCls(self._core, self._cmd_group)
		return self._harmonic

	@property
	def mixer(self):
		"""mixer commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mixer'):
			from .Mixer import MixerCls
			self._mixer = MixerCls(self._core, self._cmd_group)
		return self._mixer

	@property
	def ports(self):
		"""ports commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ports'):
			from .Ports import PortsCls
			self._ports = PortsCls(self._core, self._cmd_group)
		return self._ports

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def snumber(self):
		"""snumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_snumber'):
			from .Snumber import SnumberCls
			self._snumber = SnumberCls(self._core, self._cmd_group)
		return self._snumber

	def clear(self) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:CLEar \n
		Snippet: driver.applications.k60Transient.sense.correction.cvl.clear() \n
		No command help available \n
		"""
		self._core.io.write(f'SENSe:CORRection:CVL:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:CLEar \n
		Snippet: driver.applications.k60Transient.sense.correction.cvl.clear_with_opc() \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:CVL:CLEar', opc_timeout_ms)

	def clone(self) -> 'CvlCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CvlCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PointsCls:
	"""Points commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("points", core, parent)

	def set(self, measurement_points: float) -> None:
		"""SCPI: [SENSe]:MEASure:POINts \n
		Snippet: driver.applications.k50Spurious.sense.measure.points.set(measurement_points = 1.0) \n
		Defines the maximum number of trace points within a trace. \n
			:param measurement_points: integer Range: 101 to 32001
		"""
		param = Conversions.decimal_value_to_str(measurement_points)
		self._core.io.write(f'SENSe:MEASure:POINts {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MEASure:POINts \n
		Snippet: value: float = driver.applications.k50Spurious.sense.measure.points.get() \n
		Defines the maximum number of trace points within a trace. \n
			:return: measurement_points: integer Range: 101 to 32001"""
		response = self._core.io.query_str(f'SENSe:MEASure:POINts?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.TraceFormat, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:FORMat \n
		Snippet: driver.applications.k70Vsa.calculate.formatPy.set(format_py = enums.TraceFormat.BERate, window = repcap.Window.Default) \n
		This command defines the result type of the traces. Which parameters are available depends on the setting for the data
		source (see method RsFswp.Layout.Add.Window.get_ and Table 'Available result types depending on data source') . Whether
		the result type shows absolute or relative values is defined using the DISP:WIND:TRAC:Y:MODE command (see method RsFswp.
		Display.Window.Subwindow.Trace.Y.Scale.Mode.set) . \n
			:param format_py: MAGNitude | PHASe | UPHase | RIMag | FREQuency | COMP | CONS | IEYE | QEYE | FEYE | CONF | COVF | RCONstellation | RSUMmary | BERate | GDELay | MOVerview | BIN | OCT | DEC | HEX | NONE MAGNitude Magnitude Absolute MOVerview Magnitude Overview Absolute (entire capture buffer) PHASe 'Phase Wrap' UPHase 'Phase Unwrap' RIMag 'Real/Imag (I/Q) ' FREQuency 'Frequency Absolute' COMP 'Vector I/Q' CONS 'Constellation I/Q' IEYE 'Eye Diagram Real (I) ' QEYE 'Eye Diagram Imag (Q) ' FEYE 'Eye Diagram Frequency' CONF 'Constellation Frequency' COVF 'Vector Frequency' RCONstellation 'Constellation I/Q (Rotated) ' RSUMmary 'Result summary' BERate 'Bit error rate' GDELay 'Frequency Response Group Delay' BIN 'Symbol table' in binary format OCT 'Symbol table' in octal format DEC 'Symbol table' in decimal format HEX 'Symbol table' in hexadecimal format
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.TraceFormat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.TraceFormat:
		"""SCPI: CALCulate<n>:FORMat \n
		Snippet: value: enums.TraceFormat = driver.applications.k70Vsa.calculate.formatPy.get(window = repcap.Window.Default) \n
		This command defines the result type of the traces. Which parameters are available depends on the setting for the data
		source (see method RsFswp.Layout.Add.Window.get_ and Table 'Available result types depending on data source') . Whether
		the result type shows absolute or relative values is defined using the DISP:WIND:TRAC:Y:MODE command (see method RsFswp.
		Display.Window.Subwindow.Trace.Y.Scale.Mode.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: format_py: MAGNitude | PHASe | UPHase | RIMag | FREQuency | COMP | CONS | IEYE | QEYE | FEYE | CONF | COVF | RCONstellation | RSUMmary | BERate | GDELay | MOVerview | BIN | OCT | DEC | HEX | NONE MAGNitude Magnitude Absolute MOVerview Magnitude Overview Absolute (entire capture buffer) PHASe 'Phase Wrap' UPHase 'Phase Unwrap' RIMag 'Real/Imag (I/Q) ' FREQuency 'Frequency Absolute' COMP 'Vector I/Q' CONS 'Constellation I/Q' IEYE 'Eye Diagram Real (I) ' QEYE 'Eye Diagram Imag (Q) ' FEYE 'Eye Diagram Frequency' CONF 'Constellation Frequency' COVF 'Vector Frequency' RCONstellation 'Constellation I/Q (Rotated) ' RSUMmary 'Result summary' BERate 'Bit error rate' GDELay 'Frequency Response Group Delay' BIN 'Symbol table' in binary format OCT 'Symbol table' in octal format DEC 'Symbol table' in decimal format HEX 'Symbol table' in hexadecimal format"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.TraceFormat)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:ADEMod:ZOOM:STARt \n
		Snippet: driver.sense.ademod.zoom.start.set(time = 1.0) \n
		The command selects the start time for the zoomed display of analog-demodulated measurements in the specified window. The
		maximum value depends on the measurement time, which is set and can be queried with the [SENSe:]ADEMod:MTIMe command. If
		the zoom function is enabled, the defined number of sweep points are displayed from the start time specified with this
		command. \n
			:param time: Range: 0 s to (measurement time – zoom length) , Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:ADEMod:ZOOM:STARt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:ZOOM:STARt \n
		Snippet: value: float = driver.sense.ademod.zoom.start.get() \n
		The command selects the start time for the zoomed display of analog-demodulated measurements in the specified window. The
		maximum value depends on the measurement time, which is set and can be queried with the [SENSe:]ADEMod:MTIMe command. If
		the zoom function is enabled, the defined number of sweep points are displayed from the start time specified with this
		command. \n
			:return: time: Range: 0 s to (measurement time – zoom length) , Unit: S"""
		response = self._core.io.query_str(f'SENSe:ADEMod:ZOOM:STARt?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CommentCls:
	"""Comment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("comment", core, parent)

	def set(self, comment: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:IQ:COMMent \n
		Snippet: driver.massMemory.store.iq.comment.set(comment = '1', store = repcap.Store.Default) \n
		This command adds a comment to a file that contains I/Q data. \n
			:param comment: String containing the comment.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.value_to_quoted_str(comment)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:IQ:COMMent {param}')

	def get(self, store=repcap.Store.Default) -> str:
		"""SCPI: MMEMory:STORe<n>:IQ:COMMent \n
		Snippet: value: str = driver.massMemory.store.iq.comment.get(store = repcap.Store.Default) \n
		This command adds a comment to a file that contains I/Q data. \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: comment: String containing the comment."""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str(f'MMEMory:STORe{store_cmd_val}:IQ:COMMent?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NtransitionCls:
	"""Ntransition commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ntransition", core, parent)

	def set(self, summary_bit: int) -> None:
		"""SCPI: STATus:QUEStionable:NTRansition \n
		Snippet: driver.status.questionable.ntransition.set(summary_bit = 1) \n
		These commands control the Negative TRansition part of a register. Setting a bit causes a 1 to 0 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:param summary_bit: No help available
		"""
		param = Conversions.decimal_value_to_str(summary_bit)
		self._core.io.write(f'STATus:QUEStionable:NTRansition {param}')

	def get(self) -> int:
		"""SCPI: STATus:QUEStionable:NTRansition \n
		Snippet: value: int = driver.status.questionable.ntransition.get() \n
		These commands control the Negative TRansition part of a register. Setting a bit causes a 1 to 0 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:return: summary_bit: No help available"""
		response = self._core.io.query_str(f'STATus:QUEStionable:NTRansition?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequencerCls:
	"""Sequencer commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequencer", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import ImmediateCls
			self._immediate = ImmediateCls(self._core, self._cmd_group)
		return self._immediate

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def refresh(self):
		"""refresh commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_refresh'):
			from .Refresh import RefreshCls
			self._refresh = RefreshCls(self._core, self._cmd_group)
		return self._refresh

	def abort(self) -> None:
		"""SCPI: INITiate:SEQuencer:ABORt \n
		Snippet: driver.initiate.sequencer.abort() \n
		This command stops the currently active sequence of measurements. You can start a new sequence any time using method
		RsFswp.Initiate.Sequencer.Immediate.set. \n
		"""
		self._core.io.write(f'INITiate:SEQuencer:ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate:SEQuencer:ABORt \n
		Snippet: driver.initiate.sequencer.abort_with_opc() \n
		This command stops the currently active sequence of measurements. You can start a new sequence any time using method
		RsFswp.Initiate.Sequencer.Immediate.set. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:SEQuencer:ABORt', opc_timeout_ms)

	def clone(self) -> 'SequencerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SequencerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	def get(self) -> List[str]:
		"""SCPI: INSTrument:LIST \n
		Snippet: value: List[str] = driver.instrument.listPy.get() \n
		This command queries all active channels. The query is useful to obtain the names of the existing channels, which are
		required to replace or delete the channels. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'INSTrument:LIST?')
		return Conversions.str_to_str_list(response)



from typing import ClassVar, List

from .Internal.Core import Core
from .Internal.InstrumentErrors import RsInstrException
from .Internal.CommandsGroup import CommandsGroup
from .Internal.VisaSession import VisaSession
from datetime import datetime, timedelta


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RsFswp:
	"""2676 total commands, 24 Subgroups, 1 group commands"""
	_driver_options = "SupportedInstrModels = FSWP/FSPN, SupportedIdnPatterns = FSWP/FSPN, SimulationIdnString = Rohde&Schwarz*FSWP50*100001*3.0.1.0007"
	_global_logging_relative_timestamp: ClassVar[datetime] = None
	_global_logging_target_stream: ClassVar = None

	def __init__(self, resource_name: str, id_query: bool = True, reset: bool = False, options: str = None, direct_session: object = None):
		"""Initializes new RsFswp session. \n
		Parameter options tokens examples:
			- ``Simulate=True`` - starts the session in simulation mode. Default: ``False``
			- ``SelectVisa=socket`` - uses no VISA implementation for socket connections - you do not need any VISA-C installation
			- ``SelectVisa=rs`` - forces usage of RohdeSchwarz Visa
			- ``SelectVisa=ivi`` - forces usage of National Instruments Visa
			- ``QueryInstrumentStatus = False`` - same as ``driver.utilities.instrument_status_checking = False``. Default: ``True``
			- ``WriteDelay = 20, ReadDelay = 5`` - Introduces delay of 20ms before each write and 5ms before each read. Default: ``0ms`` for both
			- ``OpcWaitMode = OpcQuery`` - mode for all the opc-synchronised write/reads. Other modes: StbPolling, StbPollingSlow, StbPollingSuperSlow. Default: ``StbPolling``
			- ``AddTermCharToWriteBinBLock = True`` - Adds one additional LF to the end of the binary data (some instruments require that). Default: ``False``
			- ``AssureWriteWithTermChar = True`` - Makes sure each command/query is terminated with termination character. Default: Interface dependent
			- ``TerminationCharacter = "\\r"`` - Sets the termination character for reading. Default: ``\\n`` (LineFeed or LF)
			- ``DataChunkSize = 10E3`` - Maximum size of one write/read segment. If transferred data is bigger, it is split to more segments. Default: ``1E6`` bytes
			- ``OpcTimeout = 10000`` - same as driver.utilities.opc_timeout = 10000. Default: ``30000ms``
			- ``VisaTimeout = 5000`` - same as driver.utilities.visa_timeout = 5000. Default: ``10000ms``
			- ``ViClearExeMode = Disabled`` - viClear() execution mode. Default: ``execute_on_all``
			- ``OpcQueryAfterWrite = True`` - same as driver.utilities.opc_query_after_write = True. Default: ``False``
			- ``StbInErrorCheck = False`` - if true, the driver checks errors with *STB? If false, it uses SYST:ERR?. Default: ``True``
			- ``LoggingMode = On`` - Sets the logging status right from the start. Default: ``Off``
			- ``LoggingName = 'MyDevice'`` - Sets the name to represent the session in the log entries. Default: ``'resource_name'``
			- ``LogToGlobalTarget = True`` - Sets the logging target to the class-property previously set with RsFswp.set_global_logging_target() Default: ``False``
			- ``LoggingToConsole = True`` - Immediately starts logging to the console. Default: False
			- ``LoggingToUdp = True`` - Immediately starts logging to the UDP port. Default: False
			- ``LoggingUdpPort = 49200`` - UDP port to log to. Default: 49200
		:param resource_name: VISA resource name, e.g. 'TCPIP::192.168.2.1::INSTR'
		:param id_query: if True, the instrument's model name is verified against the models supported by the driver and eventually throws an exception.
		:param reset: Resets the instrument (sends *RST command) and clears its status sybsystem.
		:param options: string tokens alternating the driver settings.
		:param direct_session: Another driver object or pyVisa object to reuse the session instead of opening a new session."""
		self._core = Core(resource_name, id_query, reset, RsFswp._driver_options, options, direct_session)
		self._core.driver_version = '3.0.1.0007'
		self._options = options
		self._add_all_global_repcaps()
		self._custom_properties_init()
		self.utilities.default_instrument_setup()
		# noinspection PyTypeChecker
		self._cmd_group = CommandsGroup("ROOT", self._core, None)

	@classmethod
	def from_existing_session(cls, session: object, options: str = None) -> 'RsFswp':
		"""Creates a new RsFswp object with the entered 'session' reused. \n
		:param session: can be another driver or a direct pyvisa session.
		:param options: string tokens alternating the driver settings."""
		# noinspection PyTypeChecker
		resource_name = None
		if hasattr(session, 'resource_name'):
			resource_name = getattr(session, 'resource_name')
		return cls(resource_name, False, False, options, session)
		
	@classmethod
	def set_global_logging_target(cls, target) -> None:
		"""Sets global common target stream that each instance can use. To use it, call the following: io.utilities.logger.set_logging_target_global().
		If an instance uses global logging target, it automatically uses the global relative timestamp (if set).
		You can set the target to None to invalidate it."""
		cls._global_logging_target_stream = target

	@classmethod
	def get_global_logging_target(cls):
		"""Returns global common target stream."""
		return cls._global_logging_target_stream

	@classmethod
	def set_global_logging_relative_timestamp(cls, timestamp: datetime) -> None:
		"""Sets global common relative timestamp for log entries. To use it, call the following: io.utilities.logger.set_relative_timestamp_global()"""
		cls._global_logging_relative_timestamp = timestamp

	@classmethod
	def set_global_logging_relative_timestamp_now(cls) -> None:
		"""Sets global common relative timestamp for log entries to this moment.
		To use it, call the following: io.utilities.logger.set_relative_timestamp_global()."""
		cls._global_logging_relative_timestamp = datetime.now()

	@classmethod
	def clear_global_logging_relative_timestamp(cls) -> None:
		"""Clears the global relative timestamp. After this, all the instances using the global relative timestamp continue logging with the absolute timestamps."""
		# noinspection PyTypeChecker
		cls._global_logging_relative_timestamp = None

	@classmethod
	def get_global_logging_relative_timestamp(cls) -> datetime or None:
		"""Returns global common relative timestamp for log entries."""
		return cls._global_logging_relative_timestamp

	def __str__(self) -> str:
		if self._core.io:
			return f"RsFswp session '{self._core.io.resource_name}'"
		else:
			return f"RsFswp with session closed"

	def get_total_execution_time(self) -> timedelta:
		"""Returns total time spent by the library on communicating with the instrument.
		This time is always shorter than get_total_time(), since it does not include gaps between the communication.
		You can reset this counter with reset_time_statistics()."""
		return self._core.io.total_execution_time

	def get_total_time(self) -> timedelta:
		"""Returns total time spent by the library on communicating with the instrument.
		This time is always shorter than get_total_time(), since it does not include gaps between the communication.
		You can reset this counter with reset_time_statistics()."""
		return datetime.now() - self._core.io.total_time_startpoint

	def reset_time_statistics(self) -> None:
		"""Resets all execution and total time counters. Affects the results of get_total_time() and get_total_execution_time()"""
		self._core.io.reset_time_statistics()

	@staticmethod
	def assert_minimum_version(min_version: str) -> None:
		"""Asserts that the driver version fulfills the minimum required version you have entered.
		This way you make sure your installed driver is of the entered version or newer."""
		min_version_list = min_version.split('.')
		curr_version_list = '3.0.1.0007'.split('.')
		count_min = len(min_version_list)
		count_curr = len(curr_version_list)
		count = count_min if count_min < count_curr else count_curr
		for i in range(count):
			minimum = int(min_version_list[i])
			curr = int(curr_version_list[i])
			if curr > minimum:
				break
			if curr < minimum:
				raise RsInstrException(f"Assertion for minimum RsFswp version failed. Current version: '3.0.1.0007', minimum required version: '{min_version}'")

	@staticmethod
	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
		"""Finds all the resources defined by the expression
			- '?*' - matches all the available instruments
			- 'USB::?*' - matches all the USB instruments
			- 'TCPIP::192?*' - matches all the LAN instruments with the IP address starting with 192
		:param expression: see the examples in the function
		:param visa_select: optional parameter selecting a specific VISA. Examples: '@ivi', '@rs'
		"""
		rm = VisaSession.get_resource_manager(visa_select)
		resources = rm.list_resources(expression)
		rm.close()
		# noinspection PyTypeChecker
		return resources

	def close(self) -> None:
		"""Closes the active RsFswp session."""
		self._core.io.close()

	def get_session_handle(self) -> object:
		"""Returns the underlying session handle."""
		return self._core.get_session_handle()

	def _add_all_global_repcaps(self) -> None:
		"""Adds all the repcaps defined as global to the instrument's global repcaps dictionary."""

	def _custom_properties_init(self) -> None:
		"""Adds all the interfaces that are custom for the driver."""
		from .CustomFiles.utilities import Utilities
		self.utilities = Utilities(self._core)
		from .CustomFiles.events import Events
		self.events = Events(self._core)
		
	def _sync_to_custom_properties(self, cloned: 'RsFswp') -> None:
		"""Synchronises the state of all the custom properties to the entered object."""
		cloned.utilities.sync_from(self.utilities)
		cloned.events.sync_from(self.events)

	@property
	def layout(self):
		"""layout commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_layout'):
			from .Implementations.Layout import LayoutCls
			self._layout = LayoutCls(self._core, self._cmd_group)
		return self._layout

	@property
	def massMemory(self):
		"""massMemory commands group. 14 Sub-classes, 3 commands."""
		if not hasattr(self, '_massMemory'):
			from .Implementations.MassMemory import MassMemoryCls
			self._massMemory = MassMemoryCls(self._core, self._cmd_group)
		return self._massMemory

	@property
	def sense(self):
		"""sense commands group. 26 Sub-classes, 0 commands."""
		if not hasattr(self, '_sense'):
			from .Implementations.Sense import SenseCls
			self._sense = SenseCls(self._core, self._cmd_group)
		return self._sense

	@property
	def calculate(self):
		"""calculate commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_calculate'):
			from .Implementations.Calculate import CalculateCls
			self._calculate = CalculateCls(self._core, self._cmd_group)
		return self._calculate

	@property
	def instrument(self):
		"""instrument commands group. 8 Sub-classes, 2 commands."""
		if not hasattr(self, '_instrument'):
			from .Implementations.Instrument import InstrumentCls
			self._instrument = InstrumentCls(self._core, self._cmd_group)
		return self._instrument

	@property
	def trace(self):
		"""trace commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Implementations.Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def display(self):
		"""display commands group. 17 Sub-classes, 0 commands."""
		if not hasattr(self, '_display'):
			from .Implementations.Display import DisplayCls
			self._display = DisplayCls(self._core, self._cmd_group)
		return self._display

	@property
	def system(self):
		"""system commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_system'):
			from .Implementations.System import SystemCls
			self._system = SystemCls(self._core, self._cmd_group)
		return self._system

	@property
	def formatPy(self):
		"""formatPy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_formatPy'):
			from .Implementations.FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def inputPy(self):
		"""inputPy commands group. 17 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .Implementations.InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def status(self):
		"""status commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_status'):
			from .Implementations.Status import StatusCls
			self._status = StatusCls(self._core, self._cmd_group)
		return self._status

	@property
	def applications(self):
		"""applications commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_applications'):
			from .Implementations.Applications import ApplicationsCls
			self._applications = ApplicationsCls(self._core, self._cmd_group)
		return self._applications

	@property
	def calibration(self):
		"""calibration commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Implementations.Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def output(self):
		"""output commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Implementations.Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def trigger(self):
		"""trigger commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Implementations.Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def triggerInvoke(self):
		"""triggerInvoke commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_triggerInvoke'):
			from .Implementations.TriggerInvoke import TriggerInvokeCls
			self._triggerInvoke = TriggerInvokeCls(self._core, self._cmd_group)
		return self._triggerInvoke

	@property
	def configure(self):
		"""configure commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_configure'):
			from .Implementations.Configure import ConfigureCls
			self._configure = ConfigureCls(self._core, self._cmd_group)
		return self._configure

	@property
	def fetch(self):
		"""fetch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fetch'):
			from .Implementations.Fetch import FetchCls
			self._fetch = FetchCls(self._core, self._cmd_group)
		return self._fetch

	@property
	def initiate(self):
		"""initiate commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_initiate'):
			from .Implementations.Initiate import InitiateCls
			self._initiate = InitiateCls(self._core, self._cmd_group)
		return self._initiate

	@property
	def read(self):
		"""read commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_read'):
			from .Implementations.Read import ReadCls
			self._read = ReadCls(self._core, self._cmd_group)
		return self._read

	@property
	def source(self):
		"""source commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_source'):
			from .Implementations.Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def unit(self):
		"""unit commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_unit'):
			from .Implementations.Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	@property
	def hardCopy(self):
		"""hardCopy commands group. 15 Sub-classes, 1 commands."""
		if not hasattr(self, '_hardCopy'):
			from .Implementations.HardCopy import HardCopyCls
			self._hardCopy = HardCopyCls(self._core, self._cmd_group)
		return self._hardCopy

	@property
	def diagnostic(self):
		"""diagnostic commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_diagnostic'):
			from .Implementations.Diagnostic import DiagnosticCls
			self._diagnostic = DiagnosticCls(self._core, self._cmd_group)
		return self._diagnostic

	def abort(self) -> None:
		"""SCPI: ABORt \n
		Snippet: driver.abort() \n
		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
		FSWP is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSWP on a parallel
		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
		commands:
			- Visa: viClear
			- GPIB: ibclr
			- RSIB: RSDLLibclr
		Now you can send the [CMDLINKRESOLVED #Abort CMDLINKRESOLVED] command on the remote channel performing the measurement. \n
		"""
		self._core.io.write(f'ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ABORt \n
		Snippet: driver.abort_with_opc() \n
		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
		FSWP is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSWP on a parallel
		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
		commands:
			- Visa: viClear
			- GPIB: ibclr
			- RSIB: RSDLLibclr
		Now you can send the [CMDLINKRESOLVED #Abort CMDLINKRESOLVED] command on the remote channel performing the measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ABORt', opc_timeout_ms)

	def clone(self) -> 'RsFswp':
		"""Creates a deep copy of the RsFswp object. Also copies:
			- All the existing Global repeated capability values
			- All the default group repeated capabilities setting \n
		Does not check the *IDN? response, and does not perform Reset.
		After cloning, you can set all the repeated capabilities settings independentely from the original group.
		Calling close() on the new object does not close the original VISA session"""
		cloned = RsFswp.from_existing_session(self.get_session_handle(), self._options)
		self._cmd_group.synchronize_repcaps(cloned)
		
		self._sync_to_custom_properties(cloned)
		return cloned

	def restore_all_repcaps_to_default(self) -> None:
		"""Sets all the Group and Global repcaps to their initial values"""
		self._cmd_group.restore_repcaps()



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CarrierCls:
	"""Carrier commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("carrier", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:ADJust:CARRier \n
		Snippet: driver.applications.k50Spurious.sense.adjust.carrier.set() \n
		Automatically detects the highest peak over the complete frequency range of the analyzer. This value is considered to be
		the reference carrier and is indicated in 'Carrier Level'. \n
		"""
		self._core.io.write(f'SENSe:ADJust:CARRier')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:ADJust:CARRier \n
		Snippet: driver.applications.k50Spurious.sense.adjust.carrier.set_with_opc() \n
		Automatically detects the highest peak over the complete frequency range of the analyzer. This value is considered to be
		the reference carrier and is indicated in 'Carrier Level'. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ADJust:CARRier', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 6 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def preset(self):
		"""preset commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	@property
	def sync(self):
		"""sync commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	def save(self, filename: str) -> None:
		"""SCPI: [SENSe]:DDEMod:STANdard:SAVE \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.standard.save(filename = '1') \n
		This command stores the current settings of the vector signal analysis as a new user-defined digital standard.
		If the name of the digital standard is already in use, an error message is output and a new name has to be selected.
		It is recommended that you define a comment before storing the standard. \n
			:param filename: The path and file name to which the settings are stored.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:STANdard:SAVE {param}')

	def delete(self, filename: str) -> None:
		"""SCPI: [SENSe]:DDEMod:STANdard:DELete \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.standard.delete(filename = '1') \n
		This command deletes a specified digital standard file in the vector signal analysis. \n
			:param filename: File name including the path for the digital standard file
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:STANdard:DELete {param}')

	def clone(self) -> 'StandardCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StandardCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 22 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	@property
	def range(self):
		"""range commands group. 13 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	def save(self, filename: str) -> None:
		"""SCPI: [SENSe]:LIST:SAVE \n
		Snippet: driver.applications.k50Spurious.sense.listPy.save(filename = '1') \n
		Saves the current range setup to a user-defined comma-separated (.csv) file for later use. The values are stored in the
		following order for each range: <No>,<Start>,<Stop>,<TNRStart>,<TNRStop>,<LimitOffset>,<PeakExcursion>,<SNR>,<AutoRBW>,
		<RBW>,<MaxFinalRBW>,<Detector>,<DetLength>,<Reserved>,<RefLevel>,<RFAttenuation>,<Preamp> \n
			:param filename: String containing the path and name of the file.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:LIST:SAVE {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SENSe]:LIST:LOAD \n
		Snippet: driver.applications.k50Spurious.sense.listPy.load(filename = '1') \n
		Loads a stored range setup from a .csv file. The current settings in the table are overwritten by the settings in the
		file! \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:LIST:LOAD {param}')

	def clear(self) -> None:
		"""SCPI: [SENSe]:LIST:CLEar \n
		Snippet: driver.applications.k50Spurious.sense.listPy.clear() \n
		Removes all but the first range from the wide search settings table. \n
		"""
		self._core.io.write(f'SENSe:LIST:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:LIST:CLEar \n
		Snippet: driver.applications.k50Spurious.sense.listPy.clear_with_opc() \n
		Removes all but the first range from the wide search settings table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:LIST:CLEar', opc_timeout_ms)

	def clone(self) -> 'ListPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ListPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, arg_0: enums.RoscillatorFreqMode, externalRosc=repcap.ExternalRosc.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator:EXTernal:FREQuency:MODE \n
		Snippet: driver.source.external.roscillator.external.frequency.mode.set(arg_0 = enums.RoscillatorFreqMode.E10, externalRosc = repcap.ExternalRosc.Nr1) \n
		No command help available \n
			:param arg_0: No help available
			:param externalRosc: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.RoscillatorFreqMode)
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		self._core.io.write(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:EXTernal:FREQuency:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, externalRosc=repcap.ExternalRosc.Nr1) -> enums.RoscillatorFreqMode:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator:EXTernal:FREQuency:MODE \n
		Snippet: value: enums.RoscillatorFreqMode = driver.source.external.roscillator.external.frequency.mode.get(externalRosc = repcap.ExternalRosc.Nr1) \n
		No command help available \n
			:param externalRosc: optional repeated capability selector. Default value: Nr1
			:return: arg_0: No help available"""
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:EXTernal:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.RoscillatorFreqMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PresetCls:
	"""Preset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preset", core, parent)

	def set(self, result_type: enums.TracePresetType, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:PRESet \n
		Snippet: driver.applications.k60Transient.display.window.trace.preset.set(result_type = enums.TracePresetType.ALL, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param result_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(result_type, enums.TracePresetType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:PRESet {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.TracePresetType:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:PRESet \n
		Snippet: value: enums.TracePresetType = driver.applications.k60Transient.display.window.trace.preset.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: result_type: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:PRESet?')
		return Conversions.str_to_scalar_enum(response, enums.TracePresetType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NstateCls:
	"""Nstate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nstate", core, parent)

	def set(self, qamn_state: float) -> None:
		"""SCPI: [SENSe]:DDEMod:QAM:NSTate \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.qam.nstate.set(qamn_state = 1.0) \n
		This command defines the demodulation order for QAM.
			Table Header: <QAMNSTate> / Order \n
			- 16 / 16QAM
			- 16 / Pi/4-16QAM
			- 32 / 32QAM
			- 32 / Pi/4-32QAM
			- 64 / 64QAM
			- 128 / 128QAM
			- 256 / 256QAM
			- 512 / 512QAM
			- 1024 / 1024QAM \n
			:param qamn_state: No help available
		"""
		param = Conversions.decimal_value_to_str(qamn_state)
		self._core.io.write(f'SENSe:DDEMod:QAM:NSTate {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:QAM:NSTate \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.qam.nstate.get() \n
		This command defines the demodulation order for QAM.
			Table Header: <QAMNSTate> / Order \n
			- 16 / 16QAM
			- 16 / Pi/4-16QAM
			- 32 / 32QAM
			- 32 / Pi/4-32QAM
			- 64 / 64QAM
			- 128 / 128QAM
			- 256 / 256QAM
			- 512 / 512QAM
			- 1024 / 1024QAM \n
			:return: qamn_state: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:QAM:NSTate?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StepCls:
	"""Step commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("step", core, parent)

	def set(self, stepsize: float) -> None:
		"""SCPI: SOURce:GENerator:FREQuency:STEP \n
		Snippet: driver.source.generator.frequency.step.set(stepsize = 1.0) \n
		This command defines the frequency stepsize of the signal generated by the optional signal source. \n
			:param stepsize: 1 mHz | 1 Hz | 1 kHz | 1 MHz | 1 GHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(stepsize)
		self._core.io.write(f'SOURce:GENerator:FREQuency:STEP {param}')

	def get(self) -> float:
		"""SCPI: SOURce:GENerator:FREQuency:STEP \n
		Snippet: value: float = driver.source.generator.frequency.step.get() \n
		This command defines the frequency stepsize of the signal generated by the optional signal source. \n
			:return: stepsize: 1 mHz | 1 Hz | 1 kHz | 1 MHz | 1 GHz Unit: Hz"""
		response = self._core.io.query_str(f'SOURce:GENerator:FREQuency:STEP?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdcPrefilterCls:
	"""AdcPrefilter commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("adcPrefilter", core, parent)

	def set(self, mode: enums.AdcPreFilterMode) -> None:
		"""SCPI: [SENSe]:ADEMod:ADCPrefilter \n
		Snippet: driver.sense.ademod.adcPrefilter.set(mode = enums.AdcPreFilterMode.AUTO) \n
		This command selects the bandwidth selection mode for the ADC prefilter. \n
			:param mode: AUTO Selects the analog bandwidth based on the demodulation bandwidth. WIDE Selects the largest possible analog bandwidth.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AdcPreFilterMode)
		self._core.io.write(f'SENSe:ADEMod:ADCPrefilter {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AdcPreFilterMode:
		"""SCPI: [SENSe]:ADEMod:ADCPrefilter \n
		Snippet: value: enums.AdcPreFilterMode = driver.sense.ademod.adcPrefilter.get() \n
		This command selects the bandwidth selection mode for the ADC prefilter. \n
			:return: mode: AUTO Selects the analog bandwidth based on the demodulation bandwidth. WIDE Selects the largest possible analog bandwidth."""
		response = self._core.io.query_str(f'SENSe:ADEMod:ADCPrefilter?')
		return Conversions.str_to_scalar_enum(response, enums.AdcPreFilterMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReferenceCls:
	"""Reference commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reference", core, parent)

	def set(self, arg_0: enums.DdemodFilter) -> None:
		"""SCPI: [SENSe]:DDEMod:FILTer:REFerence \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.filterPy.reference.set(arg_0 = enums.DdemodFilter.A25Fm) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.DdemodFilter)
		self._core.io.write(f'SENSe:DDEMod:FILTer:REFerence {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DdemodFilter:
		"""SCPI: [SENSe]:DDEMod:FILTer:REFerence \n
		Snippet: value: enums.DdemodFilter = driver.applications.k70Vsa.sense.ddemod.filterPy.reference.get() \n
		No command help available \n
			:return: arg_0: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:FILTer:REFerence?')
		return Conversions.str_to_scalar_enum(response, enums.DdemodFilter)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpanCls:
	"""Span commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("span", core, parent)

	@property
	def full(self):
		"""full commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_full'):
			from .Full import FullCls
			self._full = FullCls(self._core, self._cmd_group)
		return self._full

	def set(self, span: float) -> None:
		"""SCPI: [SENSe]:ADEMod:AF:SPAN \n
		Snippet: driver.sense.ademod.af.span.set(span = 1.0) \n
		This command sets the span (around the center frequency) for AF spectrum result display. The span is limited to DBW/2
		(see [SENSe:]BWIDth:DEMod) . \n
			:param span: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(span)
		self._core.io.write(f'SENSe:ADEMod:AF:SPAN {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:AF:SPAN \n
		Snippet: value: float = driver.sense.ademod.af.span.get() \n
		This command sets the span (around the center frequency) for AF spectrum result display. The span is limited to DBW/2
		(see [SENSe:]BWIDth:DEMod) . \n
			:return: span: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:ADEMod:AF:SPAN?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'SpanCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SpanCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CmapCls:
	"""Cmap commands group definition. 3 total commands, 3 Subgroups, 0 group commands
	Repeated Capability: Item, default value after init: Item.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cmap", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_item_get', 'repcap_item_set', repcap.Item.Ix1)

	def repcap_item_set(self, item: repcap.Item) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Item.Default
		Default value after init: Item.Ix1"""
		self._cmd_group.set_repcap_enum_value(item)

	def repcap_item_get(self) -> repcap.Item:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Default import DefaultCls
			self._default = DefaultCls(self._core, self._cmd_group)
		return self._default

	@property
	def hsl(self):
		"""hsl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hsl'):
			from .Hsl import HslCls
			self._hsl = HslCls(self._core, self._cmd_group)
		return self._hsl

	@property
	def pdefined(self):
		"""pdefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pdefined'):
			from .Pdefined import PdefinedCls
			self._pdefined = PdefinedCls(self._core, self._cmd_group)
		return self._pdefined

	def clone(self) -> 'CmapCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CmapCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	def set(self, current: float) -> None:
		"""SCPI: SOURce:CURRent:AUX:LIMit:HIGH \n
		Snippet: driver.source.current.auxiliary.limit.high.set(current = 1.0) \n
		This command returns the maximum current of the Vaux connector. \n
			:param current: numeric value The return value is always 0.1 A.
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SOURce:CURRent:AUX:LIMit:HIGH {param}')

	def get(self) -> float:
		"""SCPI: SOURce:CURRent:AUX:LIMit:HIGH \n
		Snippet: value: float = driver.source.current.auxiliary.limit.high.get() \n
		This command returns the maximum current of the Vaux connector. \n
			:return: current: numeric value The return value is always 0.1 A."""
		response = self._core.io.query_str(f'SOURce:CURRent:AUX:LIMit:HIGH?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsedDrivesCls:
	"""UsedDrives commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("usedDrives", core, parent)

	def set(self, state: bool = None) -> None:
		"""SCPI: MMEMory:NETWork:USEDdrives \n
		Snippet: driver.massMemory.network.usedDrives.set(state = False) \n
		This command returns a list of all network drives in use. \n
			:param state: You do not have to use the parameter. If you do not include the parameter, the command returns a list of all drives in use. This is the same behavior as if you were using the parameter OFF. ON | 1 Returns a list of all drives in use including the folder information. OFF | 0 Returns a list of all drives in use.
		"""
		param = ''
		if state:
			param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:NETWork:USEDdrives {param}'.strip())

	def get(self) -> bool:
		"""SCPI: MMEMory:NETWork:USEDdrives \n
		Snippet: value: bool = driver.massMemory.network.usedDrives.get() \n
		This command returns a list of all network drives in use. \n
			:return: state: You do not have to use the parameter. If you do not include the parameter, the command returns a list of all drives in use. This is the same behavior as if you were using the parameter OFF. ON | 1 Returns a list of all drives in use including the folder information. OFF | 0 Returns a list of all drives in use."""
		response = self._core.io.query_str(f'MMEMory:NETWork:USEDdrives?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:LINK \n
		Snippet: driver.applications.k70Vsa.calculate.marker.link.set(state = False, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		With this command markers between several screens can be coupled, i.e. use the same x-value. All screens can be linked
		with the marker x-value scaled in symbols or time, except those showing the capture buffer. If several capture buffer
		measurements are visible, their markers are coupled, too. \n
			:param state: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<m>:LINK \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.marker.link.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		With this command markers between several screens can be coupled, i.e. use the same x-value. All screens can be linked
		with the marker x-value scaled in symbols or time, except those showing the capture buffer. If several capture buffer
		measurements are visible, their markers are coupled, too. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: state: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: CALCulate<n>:DDEM:BURSt:LENGth \n
		Snippet: value: int = driver.applications.k70Vsa.calculate.ddem.burst.length.get(window = repcap.Window.Default) \n
		This command queries the length of a detected burst. Note that since the R&S FSWP VSA application has no knowledge on the
		ramp length, there is an uncertainty in the burst search algorithm. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: length: integer Number of symbols"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DDEM:BURSt:LENGth?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdemodCls:
	"""Ademod commands group definition. 42 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ademod", core, parent)

	@property
	def af(self):
		"""af commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_af'):
			from .Af import AfCls
			self._af = AfCls(self._core, self._cmd_group)
		return self._af

	@property
	def mtime(self):
		"""mtime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtime'):
			from .Mtime import MtimeCls
			self._mtime = MtimeCls(self._core, self._cmd_group)
		return self._mtime

	@property
	def set(self):
		"""set commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_set'):
			from .Set import SetCls
			self._set = SetCls(self._core, self._cmd_group)
		return self._set

	@property
	def am(self):
		"""am commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_am'):
			from .Am import AmCls
			self._am = AmCls(self._core, self._cmd_group)
		return self._am

	@property
	def fm(self):
		"""fm commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_fm'):
			from .Fm import FmCls
			self._fm = FmCls(self._core, self._cmd_group)
		return self._fm

	@property
	def pm(self):
		"""pm commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pm'):
			from .Pm import PmCls
			self._pm = PmCls(self._core, self._cmd_group)
		return self._pm

	@property
	def spectrum(self):
		"""spectrum commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spectrum'):
			from .Spectrum import SpectrumCls
			self._spectrum = SpectrumCls(self._core, self._cmd_group)
		return self._spectrum

	@property
	def zoom(self):
		"""zoom commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_zoom'):
			from .Zoom import ZoomCls
			self._zoom = ZoomCls(self._core, self._cmd_group)
		return self._zoom

	@property
	def squelch(self):
		"""squelch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_squelch'):
			from .Squelch import SquelchCls
			self._squelch = SquelchCls(self._core, self._cmd_group)
		return self._squelch

	@property
	def preset(self):
		"""preset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	@property
	def adcPrefilter(self):
		"""adcPrefilter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adcPrefilter'):
			from .AdcPrefilter import AdcPrefilterCls
			self._adcPrefilter = AdcPrefilterCls(self._core, self._cmd_group)
		return self._adcPrefilter

	def clone(self) -> 'AdemodCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AdemodCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfrequencyCls:
	"""Cfrequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfrequency", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: DIAGnostic:SERVice:INPut:RF:CFRequency \n
		Snippet: driver.diagnostic.service.inputPy.rf.cfrequency.set(frequency = 1.0) \n
		No command help available \n
			:param frequency: No help available
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'DIAGnostic:SERVice:INPut:RF:CFRequency {param}')

	def get(self) -> float:
		"""SCPI: DIAGnostic:SERVice:INPut:RF:CFRequency \n
		Snippet: value: float = driver.diagnostic.service.inputPy.rf.cfrequency.get() \n
		No command help available \n
			:return: frequency: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:INPut:RF:CFRequency?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConfigureCls:
	"""Configure commands group definition. 12 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("configure", core, parent)

	@property
	def correction(self):
		"""correction commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def listPy(self):
		"""listPy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def single(self):
		"""single commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_single'):
			from .Single import SingleCls
			self._single = SingleCls(self._core, self._cmd_group)
		return self._single

	@property
	def mode(self):
		"""mode commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def control(self):
		"""control commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	@property
	def measurement(self):
		"""measurement commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measurement'):
			from .Measurement import MeasurementCls
			self._measurement = MeasurementCls(self._core, self._cmd_group)
		return self._measurement

	def clone(self) -> 'ConfigureCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ConfigureCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StructureCls:
	"""Structure commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("structure", core, parent)

	# noinspection PyTypeChecker
	class StructureStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Name: List[str]: string Name of the subframe. Duplicate names are allowed.
			- Nof_Symbols: List[float]: integer The number of symbols the subframe consists of. For pattern subframes, the number of symbols must correspond to the number of symbols defined using[SENSe:]DDEMod:SEARch:SYNC:DATA.
			- Modulation: List[enums.FrameModulationB]: DATA | PATTern Determines which modulation type is used to demodulate the subframe. The modulation for the 'previous frame' and 'next frame' are defined by separate commands (see [SENSe:]DDEMod:PATTern:FRAMe:EDIT:PREVious:MODulation and [SENSe:]DDEMod:PATTern:FRAMe:EDIT:NEXT:MODulation) . DATA The modulation type defined for data symbols is used (see [SENSe:]DDEMod:MAPPing[:VALue]) . PATTern The modulation type defined for patterns is used (see [SENSe:]DDEMod:PATTern:MAPPing[:VALue]) .
			- Type_Py: List[enums.FrameModulationB]: DATA | PATTern Determines whether the demodulated data in the subframe is known or unknown by the R&S FSWP VSA application. PATTern The data is assumed to correspond with the pattern definition (see [SENSe:]DDEMod:SEARch:SYNC:DATA) . Not available for modulation type: 'DATA'. Only one subframe is allowed to be of type 'PATTern'. DATA The data is unknown. Used for data symbols or header information.
			- Boosting: List[float]: numeric value For subframes with gain values different to the data symbols, define a different boosting factor to be applied to the reference power. Range: 0.1 to 60
			- Description: List[str]: string Description for an individual subframe. Use an empty string ('') to leave out the description."""
		__meta_args_list = [
			ArgStruct('Name', DataType.StringList, None, False, True, 1),
			ArgStruct('Nof_Symbols', DataType.FloatList, None, False, True, 1),
			ArgStruct('Modulation', DataType.EnumList, enums.FrameModulationB, False, True, 1),
			ArgStruct('Type_Py', DataType.EnumList, enums.FrameModulationB, False, True, 1),
			ArgStruct('Boosting', DataType.FloatList, None, False, True, 1),
			ArgStruct('Description', DataType.StringList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Name: List[str] = None
			self.Nof_Symbols: List[float] = None
			self.Modulation: List[enums.FrameModulationB] = None
			self.Type_Py: List[enums.FrameModulationB] = None
			self.Boosting: List[float] = None
			self.Description: List[str] = None

	def set(self, structure: StructureStruct) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:STRucture \n
		Snippet with structure: \n
		structure = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.structure.StructureStruct() \n
		structure.Name: List[str] = ['1', '2', '3'] \n
		structure.Nof_Symbols: List[float] = [1.1, 2.2, 3.3] \n
		structure.Modulation: List[enums.FrameModulationB] = [FrameModulationB.DATA, FrameModulationB.PATTern] \n
		structure.Type_Py: List[enums.FrameModulationB] = [FrameModulationB.DATA, FrameModulationB.PATTern] \n
		structure.Boosting: List[float] = [1.1, 2.2, 3.3] \n
		structure.Description: List[str] = ['1', '2', '3'] \n
		driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.structure.set(structure) \n
		Defines the frame structure for a previously loaded file. For each subframe, all parameters must be defined. This command
		is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. Note that the file
		must be loaded for editing before the structure can be defined using this command (see [SENSe:]DDEMod:PATTern:FRAMe:EDIT)
		. Loading the file for use in the current measurement is not sufficient (see [SENSe:]DDEMod:PATTern:FRAMe:LOAD) .
		Therefore, you can edit a frame structure while simultaneously performing a measurement with another frame structure
		configuration. The configuration is only stored by a subsequent [SENSe:]DDEMod:PATTern:FRAMe:EDIT:SAVE command.
		The modulation for the 'previous frame' and 'next frame' are defined by separate commands (see
		[SENS:]DDEM:PATT:FRAM:PREV:... and [SENS:]DDEM:PATT:FRAM:NEXT:...) . \n
			:param structure: for set value, see the help for StructureStruct structure arguments.
		"""
		self._core.io.write_struct(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:STRucture', structure)

	def get(self) -> StructureStruct:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:STRucture \n
		Snippet: value: StructureStruct = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.structure.get() \n
		Defines the frame structure for a previously loaded file. For each subframe, all parameters must be defined. This command
		is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. Note that the file
		must be loaded for editing before the structure can be defined using this command (see [SENSe:]DDEMod:PATTern:FRAMe:EDIT)
		. Loading the file for use in the current measurement is not sufficient (see [SENSe:]DDEMod:PATTern:FRAMe:LOAD) .
		Therefore, you can edit a frame structure while simultaneously performing a measurement with another frame structure
		configuration. The configuration is only stored by a subsequent [SENSe:]DDEMod:PATTern:FRAMe:EDIT:SAVE command.
		The modulation for the 'previous frame' and 'next frame' are defined by separate commands (see
		[SENS:]DDEM:PATT:FRAM:PREV:... and [SENS:]DDEM:PATT:FRAM:NEXT:...) . \n
			:return: structure: for return value, see the help for StructureStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:STRucture?', self.__class__.StructureStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, fit_offset: float, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust:ALIGnment:OFFSet \n
		Snippet: driver.applications.k70Vsa.calculate.trace.adjust.alignment.offset.set(fit_offset = 1.0, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param fit_offset: Unit: SYM
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(fit_offset)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:ALIGnment:OFFSet {param}')

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust:ALIGnment:OFFSet \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.trace.adjust.alignment.offset.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: fit_offset: Unit: SYM"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:ALIGnment:OFFSet?')
		return Conversions.str_to_float(response)
